package org.hello.vaadin.springboot;

import com.vaadin.flow.component.AttachEvent;
import com.vaadin.flow.component.Composite;
import com.vaadin.flow.component.dependency.HtmlImport;
import com.vaadin.flow.component.grid.Grid;
import com.vaadin.flow.component.html.Div;
import com.vaadin.flow.component.textfield.TextField;
import com.vaadin.flow.data.value.ValueChangeMode;
import com.vaadin.flow.router.Route;

@Route("")
@HtmlImport("styles/shared-styles.html")
public class HelloWorldComponent extends Composite<Div> {

    @Override
    protected void onAttach(AttachEvent attachEvent) {
        Grid<Person> grid = new Grid<>(Person.class);

        grid.removeColumnByKey("id");
        grid.setColumns("firstName", "lastName", "age",
                "phoneNumber");

        Grid.Column firstNameColumn = grid.getColumnByKey("firstName");
        firstNameColumn.setHeader(getFilterField("firstName", "First Name"));

        Grid.Column lastNameColumn = grid.getColumnByKey("lastName");
        lastNameColumn.setHeader(getFilterField("lastName", "Last Name"));

        Grid.Column ageColumn = grid.getColumnByKey("age");
        ageColumn.setHeader(getFilterField("age", "Age"));

        Grid.Column phoneNumberColumn = grid.getColumnByKey("phoneNumber");
        phoneNumberColumn.setHeader(getFilterField("phoneNumber", "Phone Number"));

        getContent().add(grid);
    }

    private TextField getFilterField(String fieldId, String filterPlaceholder) {
        var filteringField = new TextField();
        filteringField.setValueChangeMode(ValueChangeMode.EAGER);
        filteringField.setId(fieldId);
        filteringField.setPlaceholder(filterPlaceholder);
        return filteringField;
    }

    public static class Person {
        private int id;
        private String firstName;
        private String lastName;
        private int age;
        private String phoneNumber;

        public Person(int id, String firstName, String lastName, int age,
                      String phoneNumber) {
            super();
            this.id = id;
            this.firstName = firstName;
            this.lastName = lastName;
            this.age = age;
            this.phoneNumber = phoneNumber;
        }

        public int getId() {
            return id;
        }

        public String getFirstName() {
            return firstName;
        }

        public String getLastName() {
            return lastName;
        }

        public int getAge() {
            return age;
        }

        public String getPhoneNumber() {
            return phoneNumber;
        }
    }
}
